import {Box, TextField} from '@mui/material'
import {Edit} from '@refinedev/mui'
import {useForm} from '@refinedev/react-hook-form'
import {Controller} from 'react-hook-form'
import React from 'react'

import SimpleMDE from 'react-simplemde-editor'
import 'easymde/dist/easymde.min.css'

const MemoizedSimpleMDE = React.memo(SimpleMDE)

export const ArticleEdit = () => {
  const {
    saveButtonProps,
    register,
    control,
    formState: {errors},
  } = useForm()

  const simpleMDEOptions = React.useMemo(
    () => ({
      placeholder: 'Введите контент в формате Markdown...',
      spellChecker: false,
    }),
    [],
  )

  return (
    <Edit saveButtonProps={saveButtonProps}>
      <Box component="form" sx={{display: 'flex', flexDirection: 'column'}} autoComplete="off">
        <TextField
          {...register('heading', {
            required: 'Это поле является обязательным',
          })}
          error={!!(errors as any)?.heading}
          helperText={(errors as any)?.heading?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{shrink: true}}
          type="text"
          label="Заголовок"
          name="heading"
        />

        <Controller control={control} name="body" rules={{required: 'Это поле является обязательным'}} defaultValue="" render={({field: {onChange, value}}) => <MemoizedSimpleMDE value={value} onChange={onChange} options={simpleMDEOptions} className="my-markdown-editor" />} />
      </Box>
    </Edit>
  )
}
