import React, {useState, useEffect} from 'react'
import {DataGrid, type GridColDef, type GridColumnVisibilityModel} from '@mui/x-data-grid'
import {DeleteButton, EditButton, List, ShowButton, useDataGrid} from '@refinedev/mui'
import {Box, Button, Stack} from '@mui/material'

import Cookies from 'js-cookie'
import {localeText} from '../../locales/ru/localeText'

export const StationList = () => {
  const {dataGridProps} = useDataGrid({resource: 'station/'})

  const initialShowCoordinates = Cookies.get('showCoordinates') === 'true'
  const [showCoordinates, setShowCoordinates] = useState(initialShowCoordinates)

  const columns = React.useMemo<GridColDef[]>(
    () => [
      {
        field: 'id',
        headerName: 'ID',
        type: 'number',
        minWidth: 70,
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'name',
        headerName: 'Название',
        type: 'string',
        minWidth: 300,
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'latitude',
        headerName: 'Широта',
        type: 'number',
        minWidth: 150,
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'longitude',
        headerName: 'Долгота',
        type: 'number',
        minWidth: 150,
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'description',
        headerName: 'Описание',
        type: 'string',
        display: 'flex',
        align: 'left',
        headerAlign: 'left',
        flex: 1,
      },
      {
        field: 'actions',
        headerName: 'Действия',
        align: 'right',
        headerAlign: 'center',
        minWidth: 120,
        sortable: false,
        display: 'flex',
        renderCell: function render({row}) {
          return (
            <>
              <EditButton hideText recordItemId={row.id} />
              <ShowButton hideText recordItemId={row.id} />
              <DeleteButton hideText recordItemId={row.id} />
            </>
          )
        },
      },
    ],
    [],
  )
  const [columnVisibilityModel, setColumnVisibilityModel] = useState<GridColumnVisibilityModel>({
    latitude: showCoordinates,
    longitude: showCoordinates,
  })

  useEffect(() => {
    setColumnVisibilityModel({
      latitude: showCoordinates,
      longitude: showCoordinates,
    })
    Cookies.set('showCoordinates', String(showCoordinates))
  }, [showCoordinates])

  const toggleCoordinates = () => {
    setShowCoordinates((prev) => !prev)
  }

  return (
    <List>
      <Stack gap={2.5}>
        <DataGrid {...dataGridProps} columns={columns} localeText={localeText} getRowId={(row: any) => row.id} columnVisibilityModel={columnVisibilityModel} onColumnVisibilityModelChange={(model) => setColumnVisibilityModel(model)} />

        <Box sx={{mb: 2}}>
          <Button variant="contained" onClick={toggleCoordinates}>
            {showCoordinates ? 'Скрыть координаты' : 'Показать координаты'}
          </Button>
        </Box>
      </Stack>
    </List>
  )
}
