import {Autocomplete, Box, TextField, FormControl, InputLabel, Select, MenuItem, Typography} from '@mui/material'
import {Create, useAutocomplete} from '@refinedev/mui'
import {useForm} from '@refinedev/react-hook-form'
import {Controller} from 'react-hook-form'

import {VEHICLE_TYPES} from '../../lib/constants'

export const VehicleCreate = () => {
  const {
    saveButtonProps,
    refineCore: {formLoading},
    register,
    control,
    formState: {errors},
  } = useForm({})

  const {autocompleteProps: cityAutocompleteProps} = useAutocomplete({
    resource: 'city',
  })

  return (
    <Create isLoading={formLoading} saveButtonProps={saveButtonProps}>
      <Box component="form" sx={{display: 'flex', flexDirection: 'column'}} autoComplete="off">
        <TextField
          {...register('tail_number', {
            required: 'Это поле является обязательным',
            valueAsNumber: true,
          })}
          error={!!(errors as any)?.tail_number}
          helperText={(errors as any)?.tail_number?.message}
          margin="normal"
          fullWidth
          InputLabelProps={{shrink: true}}
          type="number"
          label="Номер рейса"
          name="tail_number"
        />

        <FormControl fullWidth margin="normal" error={!!errors.type}>
          <InputLabel id="vehicle-type-label">Выберите тип</InputLabel>
          <Select
            labelId="vehicle-type-label"
            label="Выберите тип"
            {...register('type', {
              required: 'Это поле является обязательным',
              valueAsNumber: true,
            })}
            defaultValue=""
          >
            {VEHICLE_TYPES.map((option) => (
              <MenuItem key={option.value} value={option.value}>
                {option.label}
              </MenuItem>
            ))}
          </Select>
          {errors.type && (
            <Typography variant="caption" color="error">
              {!!(errors as any)?.message}
            </Typography>
          )}
        </FormControl>

        <Controller
          control={control}
          name="city_id"
          rules={{required: 'Это поле является обязательным'}}
          defaultValue={null}
          render={({field}) => (
            <Autocomplete
              {...cityAutocompleteProps}
              value={cityAutocompleteProps.options.find((option) => option.id === field.value) || null}
              onChange={(_, value) => {
                field.onChange(value?.id || '')
              }}
              getOptionLabel={(item) => {
                return item ? item.name : ''
              }}
              isOptionEqualToValue={(option, value) => {
                return option.id === value?.id
              }}
              renderInput={(params) => <TextField {...params} label="Выберите город" margin="normal" variant="outlined" error={!!errors.city_id} helperText={(errors as any)?.city_id?.message} required />}
            />
          )}
        />
      </Box>
    </Create>
  )
}
